<?php
/**
 * Copyright ©  All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace FiloBlu\Giftwraptab\Helper;

use Magento\Framework\App\Helper\AbstractHelper;

class Data extends AbstractHelper
{

    protected $resourceConnection;
    protected $connection;
    protected $wrappingRepository;
    protected $wrappingItemRepository;

    /**
     * @param \Magento\Framework\App\Helper\Context $context
     */
    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        \Magento\Framework\App\ResourceConnection $resourceConnection,
        \Magento\GiftMessage\Api\OrderRepositoryInterface $wrappingRepository,
        \Magento\GiftMessage\Api\OrderItemRepositoryInterface $wrappingItemRepository
    ) {
        parent::__construct($context);
        $this->resourceConnection = $resourceConnection;
        $this->wrappingRepository = $wrappingRepository;
        $this->wrappingItemRepository = $wrappingItemRepository;
    }

    public function haveGiftWraps(\Magento\Sales\Api\Data\OrderInterface $order){
        if ($order->getGiftMessageId()){
            return true;
        }
        return $this->haveItemsGiftWraps($order);
    }
    public function haveItemsGiftWraps(\Magento\Sales\Api\Data\OrderInterface $order){
        $allItems = $order->getAllItems();
        foreach ($allItems as $item) {
            if ($item->getGiftMessageId()){
                return true;
            }
        }
        return false;
    }

    protected function getConnection()
    {
        if (!$this->connection) {
            $this->connection = $this->resourceConnection->getConnection('core_read');
        }
        return $this->connection;
    }

    /**
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getWrapping(\Magento\Sales\Api\Data\OrderInterface $order){
        try {
            return $this->wrappingRepository->get($order->getEntityId());
        } catch (\Exception $e){
            return false;
        }
    }

    /**
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getItemWrapping(\Magento\Sales\Api\Data\OrderItemInterface $orderItem){
        try {
            return $this->wrappingItemRepository->get($orderItem->getOrderId(), $orderItem->getItemId());
        } catch (\Exception $e){
            return false;
        }
    }
}

